@@ -171,6 +171,14 @@ double Angle::Degrees() const
 
 
 
+// Convert an Angle object to degrees, in the range 0 to 360.
+double Angle::AbsDegrees() const
+{
+	return angle / DEG_TO_STEP;
+}
+
+
+
 // Return a point rotated by this angle around (0, 0).
 Point Angle::Rotate(const Point &point) const
 {
@@ -183,6 +191,19 @@ Point Angle::Rotate(const Point &point) const
 
 
 
+// Judge whether this is inside from "base" to "limit."
+// The range from "base" to "limit" is expressed by "clock" orientation.
+bool Angle::IsInRange(const Angle& base, const Angle& limit) const
+{
+	// Choose an edge of the arc as the reference angle (base) and
+	// compare relative angles to decide whether this is in the range.
+	Angle normalizedLimit = limit - base;
+	Angle normalizedTarget = *this - base;
+	return normalizedTarget.angle <= normalizedLimit.angle;
+}
+
+
+
 // Constructor using Angle's internal representation.
 Angle::Angle(const int32_t angle)
 	: angle(angle)
