@@ -17,8 +17,8 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #include "Angle.h"
 #include "Point.h"
+#include "Swizzle.h"
 
-#include <cstdint>
 #include <string>
 
 class DataNode;
@@ -36,8 +36,9 @@ public:
 	// Constructors.
 	Body() = default;
 	Body(const Sprite *sprite, Point position, Point velocity = Point(), Angle facing = Angle(),
-		double zoom = 1., double alpha = 1.);
-	Body(const Body &sprite, Point position, Point velocity = Point(), Angle facing = Angle(), double zoom = 1.);
+		double zoom = 1., Point scale = Point(1., 1.), double alpha = 1.);
+	Body(const Body &sprite, Point position, Point velocity = Point(), Angle facing = Angle(),
+		double zoom = 1., Point scale = Point(1., 1.), double alpha = 1.);
 
 	// Check that this Body has a sprite and that the sprite has at least one frame.
 	bool HasSprite() const;
@@ -49,7 +50,7 @@ public:
 	// Get the farthest a part of this sprite can be from its center.
 	double Radius() const;
 	// Which color swizzle should be applied to the sprite?
-	int GetSwizzle() const;
+	const Swizzle *GetSwizzle() const;
 	// Get the sprite frame and mask for the given time step.
 	float GetFrame(int step = -1) const;
 	const Mask &GetMask(int step = -1) const;
@@ -61,7 +62,7 @@ public:
 	const Angle &Facing() const;
 	Point Unit() const;
 	double Zoom() const;
-	double Scale() const;
+	Point Scale() const;
 
 	// Check if this object is marked for removal from the game.
 	bool ShouldBeRemoved() const;
@@ -76,7 +77,7 @@ public:
 	// Set the sprite.
 	void SetSprite(const Sprite *sprite);
 	// Set the color swizzle.
-	void SetSwizzle(int swizzle);
+	void SetSwizzle(const Swizzle *swizzle);
 
 	// Functions determining the current alpha value of the body,
 	// dependent on the position of the body relative to the center of the screen.
@@ -104,12 +105,12 @@ protected:
 	Point position;
 	Point velocity;
 	Angle angle;
+	Point scale = Point(1., 1.);
 	Point center;
 	Point rotatedCenter;
 	// A zoom of 1 means the sprite should be drawn at half size. For objects
 	// whose sprites should be full size, use zoom = 2.
 	float zoom = 1.f;
-	float scale = 1.f;
 
 	double alpha = 1.;
 	// The maximum distance at which the body is visible, and at which it becomes invisible again.
@@ -130,7 +131,7 @@ private:
 	// Animation parameters.
 	const Sprite *sprite = nullptr;
 	// Allow objects based on this one to adjust their frame rate and swizzle.
-	int swizzle = 0;
+	const Swizzle *swizzle = Swizzle::None();
 
 	float frameRate = 2.f / 60.f;
 	int delay = 0;
