@@ -71,6 +71,10 @@ private:
 	int lifetime = 0;
 	int randomLifetime = 0;
 
+	// If set, this effect's scale can be modified based on the "zoom" of the object it is used on.
+	// For example, engine points for afterburner effects.
+	bool inheritsZoom = false;
+
 	// Allow the Visual class to access all these private members.
 	friend class Visual;
 };
