@@ -28,7 +28,6 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "GameData.h"
 #include "Information.h"
 #include "Interface.h"
-#include "text/layout.hpp"
 #include "MainPanel.h"
 #include "image/MaskManager.h"
 #include "PlayerInfo.h"
@@ -36,7 +35,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Rectangle.h"
 #include "shader/StarField.h"
 #include "StartConditionsPanel.h"
-#include "text/truncate.hpp"
+#include "text/Truncate.h"
 #include "UI.h"
 
 #include "opengl.h"
@@ -65,9 +64,14 @@ namespace {
 		}
 	}
 
-	// Convert a time_t to a human-readable time and date.
-	string TimestampString(time_t timestamp)
+	// Convert a file_time_type to a human-readable time and date.
+	string TimestampString(filesystem::file_time_type time)
 	{
+		// TODO: Replace with chrono formatting when it is properly supported.
+		auto sctp = time_point_cast<chrono::system_clock::duration>(time - filesystem::file_time_type::clock::now()
+				+ chrono::system_clock::now());
+		time_t timestamp = chrono::system_clock::to_time_t(sctp);
+
 		pair<const char*, const char*> format = TimestampFormatString(Preferences::GetDateFormat());
 		static const size_t BUF_SIZE = 25;
 		char str[BUF_SIZE];
@@ -134,7 +138,7 @@ LoadPanel::LoadPanel(PlayerInfo &player, UI &gamePanels)
 void LoadPanel::Draw()
 {
 	glClear(GL_COLOR_BUFFER_BIT);
-	GameData::Background().Draw(Point(), Point());
+	GameData::Background().Draw(Point());
 	const Font &font = FontSet::Get(14);
 
 	Information info;
@@ -272,6 +276,8 @@ void LoadPanel::Draw()
 
 bool LoadPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, bool isNewPress)
 {
+	UI::UISound sound = UI::UISound::NORMAL;
+
 	if(key == 'n')
 	{
 		// If no player is loaded, the "Enter Ship" button becomes "New Pilot."
@@ -281,6 +287,7 @@ bool LoadPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, boo
 	}
 	else if(key == 'd' && !selectedPilot.empty())
 	{
+		sound = UI::UISound::NONE;
 		GetUI()->Push(new Dialog(this, &LoadPanel::DeletePilot,
 			"Are you sure you want to delete the selected pilot, \"" + loadedInfo.Name()
 				+ "\", and all their saved games?\n\n(This will permanently delete the pilot data.)\n"
@@ -293,6 +300,7 @@ bool LoadPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, boo
 		if(it == files.end() || it->second.empty() || it->second.front().first.size() < 4)
 			return false;
 
+		sound = UI::UISound::NONE;
 		nameToConfirm.clear();
 		filesystem::path lastSave = Files::Saves() / it->second.front().first;
 		GetUI()->Push(new Dialog(this, &LoadPanel::SnapshotCallback,
@@ -301,6 +309,7 @@ bool LoadPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, boo
 	}
 	else if(key == 'R' && !selectedFile.empty())
 	{
+		sound = UI::UISound::NONE;
 		string fileName = selectedFile.substr(selectedFile.rfind('/') + 1);
 		if(!(fileName == selectedPilot + ".txt"))
 			GetUI()->Push(new Dialog(this, &LoadPanel::DeleteSave,
@@ -314,10 +323,13 @@ bool LoadPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, boo
 		if(fileName == selectedPilot + ".txt")
 			LoadCallback();
 		else
+		{
+			sound = UI::UISound::NONE;
 			GetUI()->Push(new Dialog(this, &LoadPanel::LoadCallback,
 				"If you load this snapshot, it will overwrite your current game. "
 				"Any progress will be lost, unless you have saved other snapshots. "
 				"Are you sure you want to do that?"));
+		}
 	}
 	else if(key == 'o')
 		Files::OpenUserSavesFolder();
@@ -405,6 +417,7 @@ bool LoadPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, boo
 	else
 		return false;
 
+	UI::PlaySound(sound);
 	return true;
 }
 
@@ -427,6 +440,7 @@ bool LoadPanel::Click(int x, int y, int clicks)
 				selectedPilot = it.first;
 				selectedFile = it.second.front().first;
 				centerScroll = 0;
+				UI::PlaySound(UI::UISound::NORMAL);
 			}
 	}
 	else if(snapshotBox.Contains(click))
@@ -529,7 +543,7 @@ void LoadPanel::UpdateLists()
 		if(start->first.find('~') == string::npos)
 			++start;
 		sort(start, it.second.end(),
-			[](const pair<string, time_t> &a, const pair<string, time_t> &b) -> bool
+			[](const pair<string, filesystem::file_time_type> &a, const pair<string, filesystem::file_time_type> &b) -> bool
 			{
 				return a.second > b.second || (a.second == b.second && a.first < b.first);
 			}
