@@ -106,6 +106,18 @@ void MainPanel::Step()
 		isActive = false;
 	}
 
+	// Offer the next available entering mission.
+	if(isActive && player.HasAvailableEnteringMissions() && player.Flagship())
+	{
+		Mission *mission = player.EnteringMission();
+		if(mission)
+			mission->Do(Mission::OFFER, player, GetUI());
+		else
+			player.HandleBlockedEnteringMissions(GetUI());
+		// Determine if a Dialog or ConversationPanel is being drawn next frame.
+		isActive = (GetUI()->Top().get() == this);
+	}
+
 	// Display any relevant help/tutorial messages.
 	if(isActive)
 		isActive = !ShowHelp(false);
@@ -222,8 +234,8 @@ bool MainPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, boo
 	else if(command.Has(Command::AMMO))
 	{
 		Preferences::ToggleAmmoUsage();
-		Messages::Add("Your escorts will now expend ammo: " + Preferences::AmmoUsage() + "."
-			, Messages::Importance::High);
+		Messages::Add("Your escorts will now expend ammo: " + Preferences::AmmoUsage() + ".",
+			Messages::Importance::High);
 	}
 	else if((key == SDLK_MINUS || key == SDLK_KP_MINUS) && !command)
 		Preferences::ZoomViewOut();
@@ -431,9 +443,9 @@ bool MainPanel::ShowHailPanel()
 		target.reset();
 
 	if(flagship->IsEnteringHyperspace())
-		Messages::Add("Unable to send hail: your flagship is entering hyperspace.", Messages::Importance::High);
+		Messages::Add("Unable to send hail: your flagship is entering hyperspace.", Messages::Importance::Highest);
 	else if(flagship->IsCloaked() && !flagship->Attributes().Get("cloaked communication"))
-		Messages::Add("Unable to send hail: your flagship is cloaked.", Messages::Importance::High);
+		Messages::Add("Unable to send hail: your flagship is cloaked.", Messages::Importance::Highest);
 	else if(target)
 	{
 		// If the target is out of system, always report a generic response
@@ -441,10 +453,10 @@ bool MainPanel::ShowHailPanel()
 		// not. If it's in system and jumping, report that.
 		if(target->Zoom() < 1. || target->IsDestroyed() || target->GetSystem() != player.GetSystem()
 				|| target->IsCloaked())
-			Messages::Add("Unable to hail target " + target->Noun() + ".", Messages::Importance::High);
+			Messages::Add("Unable to hail target " + target->Noun() + ".", Messages::Importance::Highest);
 		else if(target->IsEnteringHyperspace())
-			Messages::Add("Unable to send hail: " + target->Noun() + " is entering hyperspace."
-				, Messages::Importance::High);
+			Messages::Add("Unable to send hail: " + target->Noun() + " is entering hyperspace.",
+				Messages::Importance::Highest);
 		else
 		{
 			GetUI()->Push(new HailPanel(player, target,
@@ -456,11 +468,11 @@ bool MainPanel::ShowHailPanel()
 	{
 		const Planet *planet = flagship->GetTargetStellar()->GetPlanet();
 		if(!planet)
-			Messages::Add("Unable to send hail.", Messages::Importance::High);
+			Messages::Add("Unable to send hail.", Messages::Importance::Highest);
 		else if(planet->IsWormhole())
 		{
 			static const Phrase *wormholeHail = GameData::Phrases().Get("wormhole hail");
-			Messages::Add(wormholeHail->Get(), Messages::Importance::High);
+			Messages::Add(wormholeHail->Get(), Messages::Importance::Highest);
 		}
 		else if(planet->IsInhabited())
 		{
@@ -468,11 +480,11 @@ bool MainPanel::ShowHailPanel()
 			return true;
 		}
 		else
-			Messages::Add("Unable to send hail: " + planet->Noun() + " is not inhabited."
-				, Messages::Importance::High);
+			Messages::Add("Unable to send hail: " + planet->Noun() + " is not inhabited.",
+				Messages::Importance::Highest);
 	}
 	else
-		Messages::Add("Unable to send hail: no target selected.", Messages::Importance::High);
+		Messages::Add("Unable to send hail: no target selected.", Messages::Importance::Highest);
 
 	return false;
 }
@@ -687,6 +699,11 @@ void MainPanel::StepEvents(bool &isActive)
 			}
 		}
 
+		// Handle jump events from the player's flagship. This means we should check
+		// for entering missions that can be offered.
+		if((event.Type() & ShipEvent::JUMP) && flagship && event.Actor().get() == flagship)
+			player.CreateEnteringMissions();
+
 		// Remove the fully-handled event.
 		eventQueue.pop_front();
 		handledFront = false;
