@@ -28,6 +28,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 class Planet;
 class PlayerInfo;
 class System;
+class TextArea;
 
 
 
@@ -63,6 +64,7 @@ protected:
 
 
 private:
+	void InitTextArea();
 	void GeneratePlanetCards(const System &system);
 	void DrawKey();
 	void DrawInfo();
@@ -93,4 +95,8 @@ private:
 	std::vector<MapPlanetCard> planetCards;
 	// Vector offsets from the center of the "orbits" UI.
 	std::map<const Planet *, Point> planets;
+
+	std::shared_ptr<TextArea> description = nullptr;
+	bool descriptionVisible = false;
+	int descriptionXOffset;
 };
