@@ -24,6 +24,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 class PlayerInfo;
 class Ship;
 class Sprite;
+class Swizzle;
 
 
 
@@ -39,8 +40,8 @@ public:
 protected:
 	virtual const Sprite *SelectedSprite() const override;
 	virtual const Sprite *CompareSprite() const override;
-	virtual int SelectedSpriteSwizzle() const override;
-	virtual int CompareSpriteSwizzle() const override;
+	virtual const Swizzle *SelectedSpriteSwizzle() const override;
+	virtual const Swizzle *CompareSpriteSwizzle() const override;
 	virtual const ItemInfoDisplay &SelectedInfo() const override;
 	virtual const ItemInfoDisplay &CompareInfo() const override;
 	virtual const std::string &KeyLabel(int index) const override;
