@@ -26,30 +26,34 @@ using namespace std;
 
 
 
-void Person::Load(const DataNode &node)
+void Person::Load(const DataNode &node, const ConditionsStore *playerConditions,
+	const set<const System *> *visitedSystems, const set<const Planet *> *visitedPlanets)
 {
 	for(const DataNode &child : node)
 	{
-		if(child.Token(0) == "system")
-			location.Load(child);
-		else if(child.Token(0) == "frequency" && child.Size() >= 2)
+		const string &key = child.Token(0);
+		bool hasValue = child.Size() >= 2;
+
+		if(key == "system")
+			location.Load(child, visitedSystems, visitedPlanets);
+		else if(key == "frequency" && hasValue)
 			frequency = child.Value(1);
-		else if(child.Token(0) == "formation" && child.Size() >= 2)
+		else if(key == "formation" && hasValue)
 			formationPattern = GameData::Formations().Get(child.Token(1));
-		else if(child.Token(0) == "ship" && child.Size() >= 2)
+		else if(key == "ship" && hasValue)
 		{
 			// Name ships that are not the flagship with the name provided, if any.
 			// The flagship, and any unnamed fleet members, will be given the name of the Person.
 			bool setName = !ships.empty() && child.Size() >= 3;
-			ships.emplace_back(make_shared<Ship>(child));
+			ships.emplace_back(make_shared<Ship>(child, playerConditions));
 			if(setName)
 				ships.back()->SetName(child.Token(2));
 		}
-		else if(child.Token(0) == "government" && child.Size() >= 2)
+		else if(key == "government" && hasValue)
 			government = GameData::Governments().Get(child.Token(1));
-		else if(child.Token(0) == "personality")
+		else if(key == "personality")
 			personality.Load(child);
-		else if(child.Token(0) == "phrase")
+		else if(key == "phrase")
 			hail.Load(child);
 		else
 			child.PrintTrace("Skipping unrecognized attribute:");
