@@ -23,8 +23,10 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "LocationFilter.h"
 #include "Outfit.h"
 #include "Planet.h"
+#include "PlayerInfo.h"
 #include "Port.h"
 #include "Ship.h"
+#include "Shop.h"
 #include "System.h"
 
 #include <iostream>
@@ -49,13 +51,13 @@ namespace {
 
 	// Take a set of items and a set of sales and print a list of each item followed by the sales it appears in.
 	template <class Type>
-	void PrintItemSales(const Set<Type> &items, const Set<Sale<Type>> &sales,
+	void PrintItemSales(const Set<Type> &items, const Set<Shop<Type>> &sales,
 		const string &itemNoun, const string &saleNoun)
 	{
 		cout << DataWriter::Quote(itemNoun) << ',' << DataWriter::Quote(saleNoun) << '\n';
 		map<string, set<string>> itemSales;
 		for(auto &saleIt : sales)
-			for(auto &itemIt : saleIt.second)
+			for(auto &itemIt : saleIt.second.Stock())
 				itemSales[ObjectName(*itemIt)].insert(saleIt.first);
 		for(auto &itemIt : items)
 		{
@@ -71,14 +73,14 @@ namespace {
 	// Take a set of sales and print a list of each followed by the items it contains.
 	// Will fail to compile for items not of type Ship or Outfit.
 	template <class Type>
-	void PrintSales(const Set<Sale<Type>> &sales, const string &saleNoun, const string &itemNoun)
+	void PrintSales(const Set<Shop<Type>> &sales, const string &saleNoun, const string &itemNoun)
 	{
 		cout << DataWriter::Quote(saleNoun) << ';' << DataWriter::Quote(itemNoun) << '\n';
 		for(auto &saleIt : sales)
 		{
 			cout << DataWriter::Quote(saleIt.first);
 			int index = 0;
-			for(auto &item : saleIt.second)
+			for(auto &item : saleIt.second.Stock())
 				cout << (index++ ? ';' : ',') << DataWriter::Quote(ObjectName(*item));
 			cout << '\n';
 		}
@@ -654,24 +656,28 @@ namespace {
 			PrintObjectList(GameData::Systems(), "system");
 	}
 
-	void LocationFilterMatches(const char *const *argv)
+	void LocationFilterMatches(const char *const *argv, const PlayerInfo &player)
 	{
+		StellarObject::UsingMatchesCommand();
 		DataFile file(cin);
 		LocationFilter filter;
+		const set<const System *> *visitedSystems = &player.VisitedSystems();
+		const set<const Planet *> *visitedPlanets = &player.VisitedPlanets();
 		for(const DataNode &node : file)
 		{
-			if(node.Token(0) == "changes" || (node.Token(0) == "event" && node.Size() == 1))
+			const string &key = node.Token(0);
+			if(key == "changes" || (key == "event" && node.Size() == 1))
 				for(const DataNode &child : node)
-					GameData::Change(child);
-			else if(node.Token(0) == "event")
+					GameData::Change(child, player);
+			else if(key == "event")
 			{
 				const auto *event = GameData::Events().Get(node.Token(1));
 				for(const auto &change : event->Changes())
-					GameData::Change(change);
+					GameData::Change(change, player);
 			}
-			else if(node.Token(0) == "location")
+			else if(key == "location")
 			{
-				filter.Load(node);
+				filter.Load(node, visitedSystems, visitedPlanets);
 				break;
 			}
 		}
@@ -722,7 +728,7 @@ bool PrintData::IsPrintDataArgument(const char *const *argv)
 
 
 
-void PrintData::Print(const char *const *argv)
+void PrintData::Print(const char *const *argv, const PlayerInfo &player)
 {
 	for(const char *const *it = argv + 1; *it; ++it)
 	{
@@ -747,7 +753,7 @@ void PrintData::Print(const char *const *argv)
 		else if(arg == "--systems")
 			Systems(argv);
 		else if(arg == "--matches")
-			LocationFilterMatches(argv);
+			LocationFilterMatches(argv, player);
 	}
 	cout.flush();
 }
