@@ -15,10 +15,14 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #pragma once
 
+class PlayerInfo;
+
+
+
 // A class containing methods used to print ship and outfit stats to the console.
 class PrintData {
 public:
 	static bool IsPrintDataArgument(const char *const *argv);
-	static void Print(const char *const *argv);
+	static void Print(const char *const *argv, const PlayerInfo &player);
 	static void Help();
 };
