@@ -33,7 +33,7 @@ namespace {
 	// whether it should be lost on this try.
 	inline bool Check(double probability, double base)
 	{
-		return (Random::Real() < base * pow(probability, .2));
+		return (Random::Real() < base * probability);
 	}
 
 	// Returns if the missile is confused or not.
@@ -73,7 +73,7 @@ Projectile::Projectile(const Ship &parent, Point position, Angle angle, const We
 	if(weapon->RandomLifetime())
 		lifetime += Random::Int(weapon->RandomLifetime() + 1);
 
-	// Set an intial confusion turn direction.
+	// Set an initial confusion turn direction.
 	if(weapon->Homing())
 		confusionDirection = Random::Int(2) ? -1 : 1;
 }
@@ -103,7 +103,7 @@ Projectile::Projectile(const Projectile &parent, const Point &offset, const Angl
 	if(weapon->RandomLifetime())
 		lifetime += Random::Int(weapon->RandomLifetime() + 1);
 
-	// Set an intial confusion turn direction.
+	// Set an initial confusion turn direction.
 	if(weapon->Homing())
 		confusionDirection = Random::Int(2) ? -1 : 1;
 }
@@ -127,9 +127,14 @@ void Projectile::Move(vector<Visual> &visuals, vector<Projectile> &projectiles)
 		if(lifetime > -1000)
 		{
 			// This projectile didn't die in a collision. Create any death effects.
+			// Place effects ahead of the projectile by 1.5x velocity. 1x comes from
+			// the anticipated movement of the projectile on its frame of death, and
+			// 0.5x comes from the behavior of BatchDrawList::Add drawing the projectile sprite
+			// half way between its current position and its next position.
+			Point effectPosition = position + 1.5 * velocity;
 			for(const auto &it : weapon->DieEffects())
 				for(int i = 0; i < it.second; ++i)
-					visuals.emplace_back(*it.first, position, velocity, angle);
+					visuals.emplace_back(*it.first, effectPosition, velocity, angle);
 
 			for(const auto &it : weapon->Submunitions())
 				if(lifetime > -100 ? it.spawnOnNaturalDeath : it.spawnOnAntiMissileDeath)
@@ -144,6 +149,10 @@ void Projectile::Move(vector<Visual> &visuals, vector<Projectile> &projectiles)
 		MarkForRemoval();
 		return;
 	}
+	// Spawn live effects. By using the current position of the projectile and not
+	// adding any offset from the projectile's velocity, effects will appear to spawn
+	// from behind the projectile, as by the time the effect is visible, the projectile
+	// will have moved one frame forward from this position.
 	for(const auto &it : weapon->LiveEffects())
 		if(!Random::Int(it.second))
 			visuals.emplace_back(*it.first, position, velocity, angle);
@@ -275,9 +284,14 @@ void Projectile::Move(vector<Visual> &visuals, vector<Projectile> &projectiles)
 // marks the projectile as needing deletion if it has run out of hits.
 void Projectile::Explode(vector<Visual> &visuals, double intersection, Point hitVelocity)
 {
+	// Offset the placement position of effects by the projectile's velocity while
+	// also accounting for the intersection clipping. Hit effects should appear from
+	// the front of the projectile, and so are shifted forward by the full velocity
+	// of the projectile.
+	Point effectPosition = position + velocity * intersection;
 	for(const auto &it : weapon->HitEffects())
 		for(int i = 0; i < it.second; ++i)
-			visuals.emplace_back(*it.first, position + velocity * intersection, velocity, angle, hitVelocity);
+			visuals.emplace_back(*it.first, effectPosition, velocity, angle, hitVelocity);
 	// The projectile dies if it has no hits remaining.
 	if(--hitsRemaining == 0)
 	{
@@ -378,15 +392,22 @@ void Projectile::BreakTarget()
 // guided missiles.
 void Projectile::CheckLock(const Ship &target)
 {
-	double base = hasLock ? 1. : .15;
+	static const double RELOCK_RATE = .3;
+	double base = hasLock ? 1. : RELOCK_RATE;
 	hasLock = false;
 
 	// For each tracking type, calculate the probability twice every second that a
 	// lock will be lost.
 	if(weapon->Tracking())
-		hasLock |= Check(weapon->Tracking(), base);
+	{
+		double lockChance = (weapon ->Tracking());
+		double probability = lockChance / (RELOCK_RATE - (lockChance * RELOCK_RATE) + lockChance);
+		hasLock |= Check(probability, base);
+	}
 
-	// Optical tracking is about 15% for interceptors and 75% for medium warships,
+	// Optical tracking is about 1.5% for an average interceptor (250 mass),
+	// about 50% for an average medium warship (1000 mass),
+	// and about 95% for an average heavy warship (2500 mass),
 	// but can be affected by jamming.
 	if(weapon->OpticalTracking())
 	{
@@ -398,12 +419,14 @@ void Projectile::CheckLock(const Ship &target)
 			double rangeFraction = min(1., distance / jammingRange);
 			opticalJamming = (1. - rangeFraction) * opticalJamming;
 		}
-		double weight = target.Mass() * target.Mass();
-		double probability = weapon->OpticalTracking() * weight / (150000. + weight) / (1. + opticalJamming);
+		double targetMass = target.Mass();
+		double weight = targetMass * targetMass * targetMass / 1e9;
+		double lockChance = weapon->OpticalTracking() * weight / ((1. + weight) * (1. + opticalJamming));
+		double probability = lockChance / (RELOCK_RATE - (lockChance * RELOCK_RATE) + lockChance);
 		hasLock |= Check(probability, base);
 	}
 
-	// Infrared tracking is 5% when heat is zero and 100% when heat is full.
+	// Infrared tracking is zero when heat is zero and 100% when heat is full.
 	// When the missile is at under 1/3 of its maximum range, tracking is
 	// linearly increased by up to a factor of 3, representing the fact that the
 	// wavelengths of IR radiation are easier to distinguish at closer distances.
@@ -414,7 +437,8 @@ void Projectile::CheckLock(const Ship &target)
 		double multiplier = 1.;
 		if(distance <= shortRange)
 			multiplier = 2. - distance / shortRange;
-		double probability = weapon->InfraredTracking() * min(1., target.Heat() * multiplier + .05);
+		double lockChance = weapon->InfraredTracking() * min(1., target.Heat() * multiplier);
+		double probability = lockChance / (RELOCK_RATE - (lockChance * RELOCK_RATE) + lockChance);
 		hasLock |= Check(probability, base);
 	}
 
@@ -433,7 +457,8 @@ void Projectile::CheckLock(const Ship &target)
 			double rangeFraction = min(1., distance / jammingRange);
 			radarJamming = (1. - rangeFraction) * radarJamming;
 		}
-		double probability = weapon->RadarTracking() / (1. + radarJamming);
+		double lockChance = weapon->RadarTracking() / (1. + radarJamming);
+		double probability = lockChance / (RELOCK_RATE - (lockChance * RELOCK_RATE) + lockChance);
 		hasLock |= Check(probability, base);
 	}
 }
