@@ -31,6 +31,34 @@ namespace {
 
 
 
+Screen::ScreenDimensionsGuard::ScreenDimensionsGuard(int width, int height)
+	: valid(true), oldWidth(WIDTH), oldHeight(HEIGHT)
+{
+	WIDTH = width;
+	HEIGHT = height;
+}
+
+
+
+Screen::ScreenDimensionsGuard::~ScreenDimensionsGuard()
+{
+	Deactivate();
+}
+
+
+
+void Screen::ScreenDimensionsGuard::Deactivate()
+{
+	if(!valid)
+		return;
+
+	WIDTH = oldWidth;
+	HEIGHT = oldHeight;
+	valid = false;
+}
+
+
+
 void Screen::SetRaw(int width, int height)
 {
 	RAW_WIDTH = width;
