@@ -15,6 +15,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #include "UI.h"
 
+#include "audio/Audio.h"
 #include "Command.h"
 #include "Panel.h"
 #include "Screen.h"
@@ -270,6 +271,34 @@ Point UI::GetMouse()
 
 
 
+void UI::PlaySound(UISound sound)
+{
+	string name;
+	switch(sound)
+	{
+		case UISound::NORMAL:
+			name = "ui/click";
+			break;
+		case UISound::SOFT:
+			name = "ui/click soft";
+			break;
+		case UISound::SOFT_BUZZ:
+			name = "ui/buzz soft";
+			break;
+		case UISound::TARGET:
+			name = "ui/target";
+			break;
+		case UISound::FAILURE:
+			name = "ui/fail";
+			break;
+		default:
+			return;
+	}
+	Audio::Play(Audio::Get(name), SoundCategory::UI);
+}
+
+
+
 // If a push or pop is queued, apply it.
 void UI::PushOrPop()
 {
