@@ -80,6 +80,8 @@ void Weapon::LoadWeapon(const DataNode &node)
 			hardpointSprite.LoadSprite(child);
 		else if(key == "sound")
 			sound = Audio::Get(child.Token(1));
+		else if(key == "empty sound")
+			emptySound = Audio::Get(child.Token(1));
 		else if(key == "ammo")
 		{
 			int usage = (child.Size() >= 3) ? child.Value(2) : 1;
@@ -119,11 +121,13 @@ void Weapon::LoadWeapon(const DataNode &node)
 				(child.Size() >= 3) ? child.Value(2) : 1);
 			for(const DataNode &grand : child)
 			{
-				if((grand.Size() >= 2) && (grand.Token(0) == "facing"))
+				const string &grandKey = grand.Token(0);
+				bool grandHasValue = grand.Size() >= 2;
+				if(grandKey == "facing" && grandHasValue)
 					submunitions.back().facing = Angle(grand.Value(1));
-				else if((grand.Size() >= 3) && (grand.Token(0) == "offset"))
+				else if(grandKey == "offset" && grand.Size() >= 3)
 					submunitions.back().offset = Point(grand.Value(1), grand.Value(2));
-				else if(grand.Size() >= 2 && grand.Token(0) == "spawn on")
+				else if(grandKey == "spawn on" && grandHasValue)
 				{
 					submunitions.back().spawnOnNaturalDeath = false;
 					for(int j = 1; j < grand.Size(); ++j)
@@ -433,6 +437,13 @@ const Sound *Weapon::WeaponSound() const
 
 
 
+const Sound *Weapon::EmptySound() const
+{
+	return emptySound;
+}
+
+
+
 const Outfit *Weapon::Ammo() const
 {
 	return ammo.first;
